from airflow.providers.cncf.kubernetes.operators.kubernetes_pod import KubernetesPodOperator
from airflow.utils.context import Context

from pathlib import Path
import json


# Ref: https://github.com/apache/airflow/blob/main/airflow/providers/cncf/kubernetes/operators/kubernetes_pod.py
class FlowuiKubernetesPodOperator(KubernetesPodOperator):

    def execute(self, context: Context):
        # Fetch upstream tasks XCOM data and save it in a json file
        upstream_task_ids = [t.task_id for t in self.get_direct_relatives(upstream=True)]
        # upstream_xcoms = dict()
        # for tid in upstream_task_ids:
        #     upstream_xcoms[tid] = context['ti'].xcom_pull(task_ids=tid) 
        
        # Include Upstream tasks ids in an ENV var
        self.env_vars.append({
            'name': 'AIRFLOW_UPSTREAM_TASKS_IDS',
            'value': str(upstream_task_ids),
            'value_from': None
        })

        # Include volume mount subpath from dag run id, taken from context
        # Ref: https://kubernetes.io/docs/concepts/storage/volumes/#using-subpath
        dag_id = context["dag_run"].dag_id
        dag_run_id = context['run_id']
        dag_run_id_path = dag_run_id.replace("-", "_").replace(".", "_").replace(" ", "_").replace(":", "_").replace("+", "_")
        for vm in self.volume_mounts:
            if vm.name == "jobs-persistent-storage-run-data":
                vm.sub_path = f"runs/{dag_id}/{dag_run_id_path}"

        return super().execute(context=context)